FtdfDebugcontrolReg

Type Alias FtdfDebugcontrolReg 

pub type FtdfDebugcontrolReg = RegValueT<FtdfDebugcontrolReg_SPEC>;
Debug control register

Aliased Type

pub struct FtdfDebugcontrolReg { /* private fields */ }

Implementations

Source

impl FtdfDebugcontrolReg

pub fn dbg_rx_input( self, ) -> RegisterFieldBool<8, 1, 0, FtdfDebugcontrolReg_SPEC, RW>

If set to ‘1’, the Rx debug interface will be selected as input for the Rx pipeline rather than the DPHY interface signals. Note that in this mode, DBG_RX_DATA[3:0] and DBG_RX_SOF are sourced by another source (outside the scope of the LMAC) while the other Rx inputs (CCA_STAT, LQI[7:0] and ED_STAT[7:0]) are forced to 0x00.