Kbscan

Struct Kbscan 

pub struct Kbscan { /* private fields */ }

Implementations

Source

impl Kbscan

pub const fn kbscn_ctrl2_reg(&self) -> &'static Reg<KbscnCtrl2Reg_SPEC, RW>

Keyboard scanner control 2 register

pub const fn kbscn_ctrl_reg(&self) -> &'static Reg<KbscnCtrlReg_SPEC, RW>

Keyboard scanner control register

pub const fn kbscn_debounce_reg( &self, ) -> &'static Reg<KbscnDebounceReg_SPEC, RW>

Defines the debounce time for key press and release

pub const fn kbscn_matrix_size_reg( &self, ) -> &'static Reg<KbscnMatrixSizeReg_SPEC, RW>

Defines the number of rows and columns of the matrix

pub const fn kbscn_message_key_reg( &self, ) -> &'static Reg<KbscnMessageKeyReg_SPEC, RW>

Returns a key message from the message queue

pub const fn kbscn_p00_mode_reg(&self) -> &'static Reg<KbscnP00ModeReg_SPEC, RW>

Defines the keyboard mode for P00

pub const fn kbscn_p01_mode_reg(&self) -> &'static Reg<KbscnP01ModeReg_SPEC, RW>

Defines the keyboard mode for P01

pub const fn kbscn_p02_mode_reg(&self) -> &'static Reg<KbscnP02ModeReg_SPEC, RW>

Defines the keyboard mode for P02

pub const fn kbscn_p03_mode_reg(&self) -> &'static Reg<KbscnP03ModeReg_SPEC, RW>

Defines the keyboard mode for P03

pub const fn kbscn_p04_mode_reg(&self) -> &'static Reg<KbscnP04ModeReg_SPEC, RW>

Defines the keyboard mode for P04

pub const fn kbscn_p05_mode_reg(&self) -> &'static Reg<KbscnP05ModeReg_SPEC, RW>

Defines the keyboard mode for P05

pub const fn kbscn_p06_mode_reg(&self) -> &'static Reg<KbscnP06ModeReg_SPEC, RW>

Defines the keyboard mode for P06

pub const fn kbscn_p07_mode_reg(&self) -> &'static Reg<KbscnP07ModeReg_SPEC, RW>

Defines the keyboard mode for P07

pub const fn kbscn_p10_mode_reg(&self) -> &'static Reg<KbscnP10ModeReg_SPEC, RW>

Defines the keyboard mode for P10

pub const fn kbscn_p11_mode_reg(&self) -> &'static Reg<KbscnP11ModeReg_SPEC, RW>

Defines the keyboard mode for P11

pub const fn kbscn_p12_mode_reg(&self) -> &'static Reg<KbscnP12ModeReg_SPEC, RW>

Defines the keyboard mode for P12

pub const fn kbscn_p13_mode_reg(&self) -> &'static Reg<KbscnP13ModeReg_SPEC, RW>

Defines the keyboard mode for P13

pub const fn kbscn_p14_mode_reg(&self) -> &'static Reg<KbscnP14ModeReg_SPEC, RW>

Defines the keyboard mode for P14

pub const fn kbscn_p15_mode_reg(&self) -> &'static Reg<KbscnP15ModeReg_SPEC, RW>

Defines the keyboard mode for P15

pub const fn kbscn_p16_mode_reg(&self) -> &'static Reg<KbscnP16ModeReg_SPEC, RW>

Defines the keyboard mode for P16

pub const fn kbscn_p17_mode_reg(&self) -> &'static Reg<KbscnP17ModeReg_SPEC, RW>

Defines the keyboard mode for P17

pub const fn kbscn_p20_mode_reg(&self) -> &'static Reg<KbscnP20ModeReg_SPEC, RW>

Defines the keyboard mode for P20

pub const fn kbscn_p21_mode_reg(&self) -> &'static Reg<KbscnP21ModeReg_SPEC, RW>

Defines the keyboard mode for P21

pub const fn kbscn_p22_mode_reg(&self) -> &'static Reg<KbscnP22ModeReg_SPEC, RW>

Defines the keyboard mode for P22

pub const fn kbscn_p23_mode_reg(&self) -> &'static Reg<KbscnP23ModeReg_SPEC, RW>

Defines the keyboard mode for P23

pub const fn kbscn_p24_mode_reg(&self) -> &'static Reg<KbscnP24ModeReg_SPEC, RW>

Defines the keyboard mode for P24

pub const fn kbscn_p30_mode_reg(&self) -> &'static Reg<KbscnP30ModeReg_SPEC, RW>

Defines the keyboard mode for P30

pub const fn kbscn_p31_mode_reg(&self) -> &'static Reg<KbscnP31ModeReg_SPEC, RW>

Defines the keyboard mode for P31

pub const fn kbscn_p32_mode_reg(&self) -> &'static Reg<KbscnP32ModeReg_SPEC, RW>

Defines the keyboard mode for P32

pub const fn kbscn_p33_mode_reg(&self) -> &'static Reg<KbscnP33ModeReg_SPEC, RW>

Defines the keyboard mode for P33

pub const fn kbscn_p34_mode_reg(&self) -> &'static Reg<KbscnP34ModeReg_SPEC, RW>

Defines the keyboard mode for P34

pub const fn kbscn_p35_mode_reg(&self) -> &'static Reg<KbscnP35ModeReg_SPEC, RW>

Defines the keyboard mode for P35

pub const fn kbscn_p36_mode_reg(&self) -> &'static Reg<KbscnP36ModeReg_SPEC, RW>

Defines the keyboard mode for P36

pub const fn kbscn_p37_mode_reg(&self) -> &'static Reg<KbscnP37ModeReg_SPEC, RW>

Defines the keyboard mode for P37

pub const fn kbscn_p40_mode_reg(&self) -> &'static Reg<KbscnP40ModeReg_SPEC, RW>

Defines the keyboard mode for P40

pub const fn kbscn_p41_mode_reg(&self) -> &'static Reg<KbscnP41ModeReg_SPEC, RW>

Defines the keyboard mode for P41

pub const fn kbscn_p42_mode_reg(&self) -> &'static Reg<KbscnP42ModeReg_SPEC, RW>

Defines the keyboard mode for P42

pub const fn kbscn_p43_mode_reg(&self) -> &'static Reg<KbscnP43ModeReg_SPEC, RW>

Defines the keyboard mode for P43

pub const fn kbscn_p44_mode_reg(&self) -> &'static Reg<KbscnP44ModeReg_SPEC, RW>

Defines the keyboard mode for P44

pub const fn kbscn_p45_mode_reg(&self) -> &'static Reg<KbscnP45ModeReg_SPEC, RW>

Defines the keyboard mode for P45

pub const fn kbscn_p46_mode_reg(&self) -> &'static Reg<KbscnP46ModeReg_SPEC, RW>

Defines the keyboard mode for P46

pub const fn kbscn_p47_mode_reg(&self) -> &'static Reg<KbscnP47ModeReg_SPEC, RW>

Defines the keyboard mode for P47

pub const fn kbscn_status_reg(&self) -> &'static Reg<KbscnStatusReg_SPEC, RW>

keyboard scanner Interrupt status register