Peripherals

Struct Peripherals 

pub struct Peripherals {
Show 37 fields pub NVIC: Nvic, pub SCB: Scb, pub SYSTICK: SysTick, pub AES_HASH: AesHash, pub ANAMISC: Anamisc, pub APU: Apu, pub BLE: Ble, pub CACHE: Cache, pub CHIP_VERSION: ChipVersion, pub COEX: Coex, pub CRG_PER: CrgPer, pub CRG_TOP: CrgTop, pub DCDC: Dcdc, pub DEM: Dem, pub DMA: Dma, pub ECC: Ecc, pub FTDF: Ftdf, pub GP_TIMERS: GpTimers, pub GPADC: Gpadc, pub GPIO: Gpio, pub GPREG: Gpreg, pub I2C: I2C, pub I2C2: I2C2, pub IR: Ir, pub KBSCAN: Kbscan, pub OTPC: Otpc, pub QSPIC: Qspic, pub QUAD: Quad, pub SPI: Spi, pub SPI2: Spi2, pub TIMER1: Timer1, pub TRNG: Trng, pub UART: Uart, pub UART2: Uart2, pub USB: Usb, pub WAKEUP: Wakeup, pub WDOG: Wdog,
}
Required for compatibility with RTIC and other frameworks

Fields

NVIC: NvicSCB: ScbSYSTICK: SysTickAES_HASH: AesHashANAMISC: AnamiscAPU: ApuBLE: BleCACHE: CacheCHIP_VERSION: ChipVersionCOEX: CoexCRG_PER: CrgPerCRG_TOP: CrgTopDCDC: DcdcDEM: DemDMA: DmaECC: EccFTDF: FtdfGP_TIMERS: GpTimersGPADC: GpadcGPIO: GpioGPREG: GpregI2C: I2CI2C2: I2C2IR: IrKBSCAN: KbscanOTPC: OtpcQSPIC: QspicQUAD: QuadSPI: SpiSPI2: Spi2TIMER1: Timer1TRNG: TrngUART: UartUART2: Uart2USB: UsbWAKEUP: WakeupWDOG: Wdog

Implementations

Source

impl Peripherals

pub fn take() -> Option<Self>

Returns Peripheral struct multiple times Required for compatibility with RTIC and other frameworks

pub fn steal() -> Self

Returns Peripheral struct multiple times Required for compatibility with RTIC and other frameworks