pub type FtdfLmacControlStatusReg = RegValueT<FtdfLmacControlStatusReg_SPEC>;Expand description
Lmac status register
Aliased Type
pub struct FtdfLmacControlStatusReg { /* private fields */ }Implementations
Sourceimpl FtdfLmacControlStatusReg
impl FtdfLmacControlStatusReg
Sourcepub fn csma_ca_bo_stat(
self,
) -> RegisterField<24, 0xff, 1, 0, u8, u8, FtdfLmacControlStatusReg_SPEC, R>
pub fn csma_ca_bo_stat( self, ) -> RegisterField<24, 0xff, 1, 0, u8, u8, FtdfLmacControlStatusReg_SPEC, R>
The value of the currently calculated BackOff value. To be used for the sleep time calculation in case of sleep during the BackOff time.
Sourcepub fn csma_ca_resume_stat(
self,
) -> RegisterFieldBool<19, 1, 0, FtdfLmacControlStatusReg_SPEC, R>
pub fn csma_ca_resume_stat( self, ) -> RegisterFieldBool<19, 1, 0, FtdfLmacControlStatusReg_SPEC, R>
In case Csma_Ca_resume_stat is set the LMAC will
- use the value of Csma_Ca_NB_val in the CSMA-CA process rather than the initial value 0d.
- immediately perform CCA after the sleep, not waiting for the backoff time.
- reset Csma_Ca_resume_stat when it resumes CSMA-CA after the sleep.
Sourcepub fn csma_ca_nb_stat(
self,
) -> RegisterField<16, 0x7, 1, 0, u8, u8, FtdfLmacControlStatusReg_SPEC, R>
pub fn csma_ca_nb_stat( self, ) -> RegisterField<16, 0x7, 1, 0, u8, u8, FtdfLmacControlStatusReg_SPEC, R>
Current status of the Number of Backoffs.
Sourcepub fn edscanvalue(
self,
) -> RegisterField<8, 0xff, 1, 0, u8, u8, FtdfLmacControlStatusReg_SPEC, R>
pub fn edscanvalue( self, ) -> RegisterField<8, 0xff, 1, 0, u8, u8, FtdfLmacControlStatusReg_SPEC, R>
The result of an ED scan.
Sourcepub fn wakeuptimerenablestatus(
self,
) -> RegisterFieldBool<6, 1, 0, FtdfLmacControlStatusReg_SPEC, R>
pub fn wakeuptimerenablestatus( self, ) -> RegisterFieldBool<6, 1, 0, FtdfLmacControlStatusReg_SPEC, R>
Status of WakeupTimerEnable after being clocked by LP_CLK (showing it’s effective value). WakeupTimerEnableStatus can be set by setting the one-shot register WakeupTimerEnable_set and cleared by setting the one-shot register WakeupTimerEnable_clear. When WakeupTimerEnableStatus is set (after being cleared), the event counter will be reset to 0x0.
This status can be used by software since WakeupTimerEnable is used in the slow LP_CLK area. Rather than waiting for a certain number of LP_CLK periods, simply scanning this status (or enable the interrupt created by WakeupTimerEnableStatus_e) will allow software to determine if this signal has been effected. Note that the rising edge of WakeupTimerEnable will reset the Wake-up (event) counter.
Sourcepub fn ccastat(
self,
) -> RegisterFieldBool<2, 1, 0, FtdfLmacControlStatusReg_SPEC, R>
pub fn ccastat( self, ) -> RegisterFieldBool<2, 1, 0, FtdfLmacControlStatusReg_SPEC, R>
The value of a single CCA, valid when CCAstat_e is set to ‘1’.
Sourcepub fn lmacready4sleep(
self,
) -> RegisterFieldBool<1, 1, 0, FtdfLmacControlStatusReg_SPEC, R>
pub fn lmacready4sleep( self, ) -> RegisterFieldBool<1, 1, 0, FtdfLmacControlStatusReg_SPEC, R>
If set to ‘1’ this register indicates that the LMAC is ready to go to sleep.