Otpc

Struct Otpc 

pub struct Otpc { /* private fields */ }

Implementations

Source

impl Otpc

pub const fn otpc_ahbadr_reg(&self) -> &'static Reg<OtpcAhbadrReg_SPEC, RW>

AHB master start address

pub const fn otpc_celadr_reg(&self) -> &'static Reg<OtpcCeladrReg_SPEC, RW>

Macrocell start address

pub const fn otpc_ffprt_reg(&self) -> &'static Reg<OtpcFfprtReg_SPEC, RW>

Ports access to fifo logic

pub const fn otpc_ffrd_reg(&self) -> &'static Reg<OtpcFfrdReg_SPEC, RW>

The data which have taken with the latest read from the OTPC_FFPRT_REG

pub const fn otpc_mode_reg(&self) -> &'static Reg<OtpcModeReg_SPEC, RW>

Mode register

pub const fn otpc_nwords_reg(&self) -> &'static Reg<OtpcNwordsReg_SPEC, RW>

Number of words

pub const fn otpc_pctrl_reg(&self) -> &'static Reg<OtpcPctrlReg_SPEC, RW>

Bit-programming control register

pub const fn otpc_pwordh_reg(&self) -> &'static Reg<OtpcPwordhReg_SPEC, RW>

The 32 higher bits of the 64-bit word that will be programmed, when the MPROG mode is used.

pub const fn otpc_pwordl_reg(&self) -> &'static Reg<OtpcPwordlReg_SPEC, RW>

The 32 lower bits of the 64-bit word that will be programmed, when the MPROG mode is used.

pub const fn otpc_stat_reg(&self) -> &'static Reg<OtpcStatReg_SPEC, RW>

Status register

pub const fn otpc_tim1_reg(&self) -> &'static Reg<OtpcTim1Reg_SPEC, RW>

Various timing parameters of the OTP cell.

pub const fn otpc_tim2_reg(&self) -> &'static Reg<OtpcTim2Reg_SPEC, RW>

Various timing parameters of the OTP cell.