pub struct Timer1 { /* private fields */ }Implementations
Sourceimpl Timer1
impl Timer1
Sourcepub const fn captim_capture_gpio1_reg(
&self,
) -> &'static Reg<CaptimCaptureGpio1Reg_SPEC, RW>
pub const fn captim_capture_gpio1_reg( &self, ) -> &'static Reg<CaptimCaptureGpio1Reg_SPEC, RW>
Capture Timer value for event on GPIO1
Sourcepub const fn captim_capture_gpio2_reg(
&self,
) -> &'static Reg<CaptimCaptureGpio2Reg_SPEC, RW>
pub const fn captim_capture_gpio2_reg( &self, ) -> &'static Reg<CaptimCaptureGpio2Reg_SPEC, RW>
Capture Timer value for event on GPIO2
Sourcepub const fn captim_capture_high_gpio1_reg(
&self,
) -> &'static Reg<CaptimCaptureHighGpio1Reg_SPEC, RW>
pub const fn captim_capture_high_gpio1_reg( &self, ) -> &'static Reg<CaptimCaptureHighGpio1Reg_SPEC, RW>
Capture Timer high value for event on GPIO01
Sourcepub const fn captim_capture_high_gpio2_reg(
&self,
) -> &'static Reg<CaptimCaptureHighGpio2Reg_SPEC, RW>
pub const fn captim_capture_high_gpio2_reg( &self, ) -> &'static Reg<CaptimCaptureHighGpio2Reg_SPEC, RW>
Capture Timer high value for event on GPIO02
Sourcepub const fn captim_ctrl_reg(&self) -> &'static Reg<CaptimCtrlReg_SPEC, RW>
pub const fn captim_ctrl_reg(&self) -> &'static Reg<CaptimCtrlReg_SPEC, RW>
Capture Timer control register
Sourcepub const fn captim_gpio1_conf_reg(
&self,
) -> &'static Reg<CaptimGpio1ConfReg_SPEC, RW>
pub const fn captim_gpio1_conf_reg( &self, ) -> &'static Reg<CaptimGpio1ConfReg_SPEC, RW>
Capture Timer gpio1 selection
Sourcepub const fn captim_gpio2_conf_reg(
&self,
) -> &'static Reg<CaptimGpio2ConfReg_SPEC, RW>
pub const fn captim_gpio2_conf_reg( &self, ) -> &'static Reg<CaptimGpio2ConfReg_SPEC, RW>
Capture Timer gpio2 selection
Sourcepub const fn captim_prescaler_reg(
&self,
) -> &'static Reg<CaptimPrescalerReg_SPEC, RW>
pub const fn captim_prescaler_reg( &self, ) -> &'static Reg<CaptimPrescalerReg_SPEC, RW>
Capture Timer prescaler value
Sourcepub const fn captim_prescaler_val_reg(
&self,
) -> &'static Reg<CaptimPrescalerValReg_SPEC, RW>
pub const fn captim_prescaler_val_reg( &self, ) -> &'static Reg<CaptimPrescalerValReg_SPEC, RW>
Capture Timer interrupt status register
Sourcepub const fn captim_pwm_dc_reg(&self) -> &'static Reg<CaptimPwmDcReg_SPEC, RW>
pub const fn captim_pwm_dc_reg(&self) -> &'static Reg<CaptimPwmDcReg_SPEC, RW>
Capture Timer pwm dc register
Sourcepub const fn captim_pwm_freq_reg(
&self,
) -> &'static Reg<CaptimPwmFreqReg_SPEC, RW>
pub const fn captim_pwm_freq_reg( &self, ) -> &'static Reg<CaptimPwmFreqReg_SPEC, RW>
Capture Timer pwm frequency register
Sourcepub const fn captim_reload_high_reg(
&self,
) -> &'static Reg<CaptimReloadHighReg_SPEC, RW>
pub const fn captim_reload_high_reg( &self, ) -> &'static Reg<CaptimReloadHighReg_SPEC, RW>
Capture Timer reload high value and Delay in shot mode
Sourcepub const fn captim_reload_reg(&self) -> &'static Reg<CaptimReloadReg_SPEC, RW>
pub const fn captim_reload_reg(&self) -> &'static Reg<CaptimReloadReg_SPEC, RW>
Capture Timer reload value and Delay in shot mode
Sourcepub const fn captim_shotwidth_high_reg(
&self,
) -> &'static Reg<CaptimShotwidthHighReg_SPEC, RW>
pub const fn captim_shotwidth_high_reg( &self, ) -> &'static Reg<CaptimShotwidthHighReg_SPEC, RW>
Capture Timer Shot high duration in shot mode
Sourcepub const fn captim_shotwidth_reg(
&self,
) -> &'static Reg<CaptimShotwidthReg_SPEC, RW>
pub const fn captim_shotwidth_reg( &self, ) -> &'static Reg<CaptimShotwidthReg_SPEC, RW>
Capture Timer Shot duration in shot mode
Sourcepub const fn captim_status_reg(&self) -> &'static Reg<CaptimStatusReg_SPEC, RW>
pub const fn captim_status_reg(&self) -> &'static Reg<CaptimStatusReg_SPEC, RW>
Capture Timer status register
Sourcepub const fn captim_timer_hval_reg(
&self,
) -> &'static Reg<CaptimTimerHvalReg_SPEC, RW>
pub const fn captim_timer_hval_reg( &self, ) -> &'static Reg<CaptimTimerHvalReg_SPEC, RW>
Capture Timer counter high value
Sourcepub const fn captim_timer_val_reg(
&self,
) -> &'static Reg<CaptimTimerValReg_SPEC, RW>
pub const fn captim_timer_val_reg( &self, ) -> &'static Reg<CaptimTimerValReg_SPEC, RW>
Capture Timer counter value